Crate oparlint_suites

Crate oparlint_suites 

The crate that contains the lint suite implementations for the oparlint tool.

Modules

system
Lint suites for checking the system endpoint and data types of an OParl service.